from django.test import TestCase

import valuta

from product.simple_models import SimpleProduct

__author__ = "Artur Barseghyan"
__copyright__ = "2021 Artur Barseghyan"
__license__ = "GPL-2.0-only OR LGPL-2.1-or-later"
__all__ = ("TemplateTagsTestCase",)


class TemplateTagsTestCase(TestCase):
    def setUp(self):
        self.product = SimpleProduct(
            currency_code=valuta.EUR.uid,
            price=1_000,
            price_with_tax=1_200,
        )

    def test_filter_convert_to_currency_units(self):
        p = self.product

        price = p.filter_product_price_in_currency_units()
        self.assertEqual(price, "10.0")

        price_with_tax = p.filter_product_price_with_tax_in_currency_units()
        self.assertEqual(price_with_tax, "12.0")

    def test_tag_convert_to_currency_units(self):
        p = self.product

        price = p.tag_product_price_in_currency_units()
        self.assertEqual(price, "10.0")

        price_with_tax = p.tag_product_price_with_tax_in_currency_units()
        self.assertEqual(price_with_tax, "12.0")



from decimal import Decimal
from typing import Union

from django import template

from ....shortcuts import convert_to_currency_units

register = template.Library()

__author__ = "Artur Barseghyan"
__copyright__ = "2021 Artur Barseghyan"
__license__ = "GPL-2.0-only OR LGPL-2.1-or-later"
__all__ = (
    "filter_convert_to_currency_units",
    "tag_convert_to_currency_units",
)


@register.filter(name="convert_to_currency_units")
def filter_convert_to_currency_units(
    value: int, currency_code: str
) -> Union[int, float]:
    return convert_to_currency_units(currency_code, value)


@register.simple_tag(name="convert_to_currency_units")
def tag_convert_to_currency_units(
    value: int, currency_code: str
) -> Union[int, float, Decimal]:
    return convert_to_currency_units(currency_code, value)



from ..base import BaseCurrency

__author__ = "Artur Barseghyan"
__copyright__ = "2021 Artur Barseghyan"
__license__ = "GPL-2.0-only OR LGPL-2.1-or-later"
__all__ = ("SDG",)


class SDG(BaseCurrency):
    """SDG - Sudanese pound."""

    uid: str = "SDG"
    rate: int = 100



from ..base import BaseCurrency

__author__ = "Artur Barseghyan"
__copyright__ = "2021 Artur Barseghyan"
__license__ = "GPL-2.0-only OR LGPL-2.1-or-later"
__all__ = ("UGX",)


class UGX(BaseCurrency):
    """UGX - Ugandan shilling."""

    uid: str = "UGX"
    rate: int = 1
